@@ -170,13 +170,8 @@ class VoiceTextContext(c.Context):
 
     async def join(self) -> None:
         """読み上げを開始するためのデータをDBに保存します。"""
-        print(f"start: {0}".format("\n".join(f"{k}: {v}" for k, v in self.default_params.items())))
         if not await self.bot_channels.fetch(**self.default_params):
             await self.bot_channels.insert(**self.default_params)
-            print(f"insert: {0}".format("\n".join(f"{k}: {v}" for k, v in self.default_params.items())))
-
-        await self.bot_channels.update(tc=self.channel.id, **self.default_params)
-        print(f"update: tc: {self.channel.id}")
 
         await self.bot_channels.update(join_time=datetime.now(), **self.default_params)
         await self.connect()
@@ -437,10 +432,13 @@ class VoiceTextContext(c.Context):
 
     async def speak(self) -> None:
         "読み上げ関数"
+        print("start speak")
         if not await self.is_read():
             return
+        print("ok read")
 
         folder = get_folder(self.message)
+        print("folder")
 
         while self.guild.voice_client.is_playing():
             await sleep(1)
